ColorSpecs

Struct ColorSpecs 

pub struct ColorSpecs { /* private fields */ }
A merged set of color specifications.

This set of color specifications represents the various color types that are supported by the printers in this crate. A set of color specifications can be created from a sequence of UserColorSpecs.

Implementations

Source

impl ColorSpecs

pub fn new(specs: &[UserColorSpec]) -> ColorSpecs

Create color specifications from a list of user supplied specifications.

pub fn default_with_color() -> ColorSpecs

Create a default set of specifications that have color.

This is distinct from ColorSpecs’s Default implementation in that this provides a set of default color choices, where as the Default implementation provides no color choices.

pub fn path(&self) -> &ColorSpec

Return the color specification for coloring file paths.

pub fn line(&self) -> &ColorSpec

Return the color specification for coloring line numbers.

pub fn column(&self) -> &ColorSpec

Return the color specification for coloring column numbers.

pub fn matched(&self) -> &ColorSpec

Return the color specification for coloring matched text.

pub fn highlight(&self) -> &ColorSpec

Return the color specification for coloring entire line if there is a matched text.