[][src]Enum grep_printer::SummaryKind

pub enum SummaryKind {
    Count,
    CountMatches,
    PathWithMatch,
    PathWithoutMatch,
    Quiet,
}

The type of summary output (if any) to print.

Variants

Count

Show only a count of the total number of matches (counting each line at most once) found.

If the path setting is enabled, then the count is prefixed by the corresponding file path.

CountMatches

Show only a count of the total number of matches (counting possibly many matches on each line) found.

If the path setting is enabled, then the count is prefixed by the corresponding file path.

PathWithMatch

Show only the file path if and only if a match was found.

This ignores the path setting and always shows the file path. If no file path is provided, then searching will immediately stop and return an error.

PathWithoutMatch

Show only the file path if and only if a match was found.

This ignores the path setting and always shows the file path. If no file path is provided, then searching will immediately stop and return an error.

Quiet

Don't show any output and the stop the search once a match is found.

Note that if stats is enabled, then searching continues in order to compute statistics.