Struct grep_printer::ColorSpecs [−][src]
pub struct ColorSpecs { /* fields omitted */ }Expand description
A merged set of color specifications.
This set of color specifications represents the various color types that
are supported by the printers in this crate. A set of color specifications
can be created from a sequence of
UserColorSpecs.
Implementations
Create color specifications from a list of user supplied specifications.
Create a default set of specifications that have color.
This is distinct from ColorSpecs’s Default implementation in that
this provides a set of default color choices, where as the Default
implementation provides no color choices.